from setuptools import setup
import glob
import sys

sys.path += ['source']

# PyOpenGL dynamically decides which modules to load. As a result,
# py2exe/py2app can't figure out which ones are necessary, so lets manually
# include all of them!
opengl_modules = [
    'OpenGL.GL.APPLE.client_storage',
    'OpenGL.GL.APPLE.element_array',
    'OpenGL.GL.APPLE.fence',
    'OpenGL.GL.APPLE.flush_buffer_range',
    'OpenGL.GL.APPLE.specular_vector',
    'OpenGL.GL.APPLE.transform_hint',
    'OpenGL.GL.APPLE.vertex_array_object',
    'OpenGL.GL.APPLE.vertex_array_range',
    'OpenGL.GL.APPLE.ycbcr_422',
    'OpenGL.GL.ARB.color_buffer_float',
    'OpenGL.GL.ARB.depth_buffer_float',
    'OpenGL.GL.ARB.depth_texture',
    'OpenGL.GL.ARB.draw_buffers',
    'OpenGL.GL.ARB.draw_instanced',
    'OpenGL.GL.ARB.fragment_program',
    'OpenGL.GL.ARB.fragment_program_shadow',
    'OpenGL.GL.ARB.fragment_shader',
    'OpenGL.GL.ARB.framebuffer_object',
    'OpenGL.GL.ARB.framebuffer_sRGB',
    'OpenGL.GL.ARB.geometry_shader4',
    'OpenGL.GL.ARB.half_float_pixel',
    'OpenGL.GL.ARB.half_float_vertex',
    'OpenGL.GL.ARB.imaging',
    'OpenGL.GL.ARB.instanced_arrays',
    'OpenGL.GL.ARB.map_buffer_range',
    'OpenGL.GL.ARB.matrix_palette',
    'OpenGL.GL.ARB.multisample',
    'OpenGL.GL.ARB.multitexture',
    'OpenGL.GL.ARB.occlusion_query',
    'OpenGL.GL.ARB.pixel_buffer_object',
    'OpenGL.GL.ARB.point_parameters',
    'OpenGL.GL.ARB.point_sprite',
    'OpenGL.GL.ARB.shader_objects',
    'OpenGL.GL.ARB.shading_language_100',
    'OpenGL.GL.ARB.shadow',
    'OpenGL.GL.ARB.shadow_ambient',
    'OpenGL.GL.ARB.texture_border_clamp',
    'OpenGL.GL.ARB.texture_buffer_object',
    'OpenGL.GL.ARB.texture_compression',
    'OpenGL.GL.ARB.texture_compression_rgtc',
    'OpenGL.GL.ARB.texture_cube_map',
    'OpenGL.GL.ARB.texture_env_add',
    'OpenGL.GL.ARB.texture_env_combine',
    'OpenGL.GL.ARB.texture_env_crossbar',
    'OpenGL.GL.ARB.texture_env_dot3',
    'OpenGL.GL.ARB.texture_float',
    'OpenGL.GL.ARB.texture_mirrored_repeat',
    'OpenGL.GL.ARB.texture_non_power_of_two',
    'OpenGL.GL.ARB.texture_rectangle',
    'OpenGL.GL.ARB.texture_rg',
    'OpenGL.GL.ARB.transpose_matrix',
    'OpenGL.GL.ARB.vertex_array_object',
    'OpenGL.GL.ARB.vertex_blend',
    'OpenGL.GL.ARB.vertex_buffer_object',
    'OpenGL.GL.ARB.vertex_program',
    'OpenGL.GL.ARB.vertex_shader',
    'OpenGL.GL.ARB.window_pos',
    'OpenGL.GL.ATI.draw_buffers',
    'OpenGL.GL.ATI.element_array',
    'OpenGL.GL.ATI.envmap_bumpmap',
    'OpenGL.GL.ATI.fragment_shader',
    'OpenGL.GL.ATI.map_object_buffer',
    'OpenGL.GL.ATI.pixel_format_float',
    'OpenGL.GL.ATI.pn_triangles',
    'OpenGL.GL.ATI.separate_stencil',
    'OpenGL.GL.ATI.text_fragment_shader',
    'OpenGL.GL.ATI.texture_env_combine3',
    'OpenGL.GL.ATI.texture_float',
    'OpenGL.GL.ATI.texture_mirror_once',
    'OpenGL.GL.ATI.vertex_array_object',
    'OpenGL.GL.ATI.vertex_attrib_array_object',
    'OpenGL.GL.ATI.vertex_streams',
    'OpenGL.GL.DFX.multisample',
    'OpenGL.GL.DFX.tbuffer',
    'OpenGL.GL.DFX.texture_compression_FXT1',
    'OpenGL.GL.EXT.422_pixels',
    'OpenGL.GL.EXT.GL_422_pixels',
    'OpenGL.GL.EXT.abgr',
    'OpenGL.GL.EXT.bgra',
    'OpenGL.GL.EXT.bindable_uniform',
    'OpenGL.GL.EXT.blend_color',
    'OpenGL.GL.EXT.blend_equation_separate',
    'OpenGL.GL.EXT.blend_func_separate',
    'OpenGL.GL.EXT.blend_logic_op',
    'OpenGL.GL.EXT.blend_minmax',
    'OpenGL.GL.EXT.blend_subtract',
    'OpenGL.GL.EXT.clip_volume_hint',
    'OpenGL.GL.EXT.cmyka',
    'OpenGL.GL.EXT.color_matrix',
    'OpenGL.GL.EXT.color_subtable',
    'OpenGL.GL.EXT.compiled_vertex_array',
    'OpenGL.GL.EXT.convolution',
    'OpenGL.GL.EXT.coordinate_frame',
    'OpenGL.GL.EXT.copy_texture',
    'OpenGL.GL.EXT.cull_vertex',
    'OpenGL.GL.EXT.depth_bounds_test',
    'OpenGL.GL.EXT.draw_buffers2',
    'OpenGL.GL.EXT.draw_instanced',
    'OpenGL.GL.EXT.draw_range_elements',
    'OpenGL.GL.EXT.fog_coord',
    'OpenGL.GL.EXT.framebuffer_blit',
    'OpenGL.GL.EXT.framebuffer_multisample',
    'OpenGL.GL.EXT.framebuffer_object',
    'OpenGL.GL.EXT.framebuffer_sRGB',
    'OpenGL.GL.EXT.geometry_shader4',
    'OpenGL.GL.EXT.gpu_program_parameters',
    'OpenGL.GL.EXT.gpu_shader4',
    'OpenGL.GL.EXT.histogram',
    'OpenGL.GL.EXT.index_array_formats',
    'OpenGL.GL.EXT.index_func',
    'OpenGL.GL.EXT.index_material',
    'OpenGL.GL.EXT.index_texture',
    'OpenGL.GL.EXT.light_texture',
    'OpenGL.GL.EXT.misc_attribute',
    'OpenGL.GL.EXT.multi_draw_arrays',
    'OpenGL.GL.EXT.multisample',
    'OpenGL.GL.EXT.packed_depth_stencil',
    'OpenGL.GL.EXT.packed_float',
    'OpenGL.GL.EXT.packed_pixels',
    'OpenGL.GL.EXT.paletted_texture',
    'OpenGL.GL.EXT.pixel_buffer_object',
    'OpenGL.GL.EXT.pixel_transform',
    'OpenGL.GL.EXT.pixel_transform_color_table',
    'OpenGL.GL.EXT.point_parameters',
    'OpenGL.GL.EXT.polygon_offset',
    'OpenGL.GL.EXT.rescale_normal',
    'OpenGL.GL.EXT.secondary_color',
    'OpenGL.GL.EXT.separate_specular_color',
    'OpenGL.GL.EXT.shadow_funcs',
    'OpenGL.GL.EXT.shared_texture_palette',
    'OpenGL.GL.EXT.stencil_clear_tag',
    'OpenGL.GL.EXT.stencil_two_side',
    'OpenGL.GL.EXT.stencil_wrap',
    'OpenGL.GL.EXT.subtexture',
    'OpenGL.GL.EXT.texture',
    'OpenGL.GL.EXT.texture3D',
    'OpenGL.GL.EXT.texture_array',
    'OpenGL.GL.EXT.texture_buffer_object',
    'OpenGL.GL.EXT.texture_compression_latc',
    'OpenGL.GL.EXT.texture_compression_rgtc',
    'OpenGL.GL.EXT.texture_compression_s3tc',
    'OpenGL.GL.EXT.texture_cube_map',
    'OpenGL.GL.EXT.texture_env_add',
    'OpenGL.GL.EXT.texture_env_combine',
    'OpenGL.GL.EXT.texture_env_dot3',
    'OpenGL.GL.EXT.texture_filter_anisotropic',
    'OpenGL.GL.EXT.texture_integer',
    'OpenGL.GL.EXT.texture_lod_bias',
    'OpenGL.GL.EXT.texture_mirror_clamp',
    'OpenGL.GL.EXT.texture_object',
    'OpenGL.GL.EXT.texture_perturb_normal',
    'OpenGL.GL.EXT.texture_sRGB',
    'OpenGL.GL.EXT.texture_shared_exponent',
    'OpenGL.GL.EXT.timer_query',
    'OpenGL.GL.EXT.transform_feedback',
    'OpenGL.GL.EXT.vertex_array',
    'OpenGL.GL.EXT.vertex_shader',
    'OpenGL.GL.EXT.vertex_weighting',
    'OpenGL.GL.GREMEDY.frame_terminator',
    'OpenGL.GL.GREMEDY.string_marker',
    'OpenGL.GL.HP.convolution_border_modes',
    'OpenGL.GL.HP.image_transform',
    'OpenGL.GL.HP.occlusion_test',
    'OpenGL.GL.HP.texture_lighting',
    'OpenGL.GL.IBM.cull_vertex',
    'OpenGL.GL.IBM.multimode_draw_arrays',
    'OpenGL.GL.IBM.rasterpos_clip',
    'OpenGL.GL.IBM.texture_mirrored_repeat',
    'OpenGL.GL.IBM.vertex_array_lists',
    'OpenGL.GL.INGR.blend_func_separate',
    'OpenGL.GL.INGR.color_clamp',
    'OpenGL.GL.INGR.interlace_read',
    'OpenGL.GL.INGR.palette_buffer',
    'OpenGL.GL.INTEL.parallel_arrays',
    'OpenGL.GL.INTEL.texture_scissor',
    'OpenGL.GL.MESA.pack_invert',
    'OpenGL.GL.MESA.resize_buffers',
    'OpenGL.GL.MESA.window_pos',
    'OpenGL.GL.MESA.ycbcr_texture',
    'OpenGL.GL.MESAX.texture_stack',
    'OpenGL.GL.NV.blend_square',
    'OpenGL.GL.NV.conditional_render',
    'OpenGL.GL.NV.copy_depth_to_color',
    'OpenGL.GL.NV.depth_buffer_float',
    'OpenGL.GL.NV.depth_clamp',
    'OpenGL.GL.NV.evaluators',
    'OpenGL.GL.NV.fence',
    'OpenGL.GL.NV.float_buffer',
    'OpenGL.GL.NV.fog_distance',
    'OpenGL.GL.NV.fragment_program',
    'OpenGL.GL.NV.fragment_program2',
    'OpenGL.GL.NV.fragment_program4',
    'OpenGL.GL.NV.fragment_program_option',
    'OpenGL.GL.NV.framebuffer_multisample_coverage',
    'OpenGL.GL.NV.geometry_program4',
    'OpenGL.GL.NV.geometry_shader4',
    'OpenGL.GL.NV.gpu_program4',
    'OpenGL.GL.NV.half_float',
    'OpenGL.GL.NV.light_max_exponent',
    'OpenGL.GL.NV.multisample_filter_hint',
    'OpenGL.GL.NV.occlusion_query',
    'OpenGL.GL.NV.packed_depth_stencil',
    'OpenGL.GL.NV.parameter_buffer_object',
    'OpenGL.GL.NV.pixel_data_range',
    'OpenGL.GL.NV.point_sprite',
    'OpenGL.GL.NV.present_video',
    'OpenGL.GL.NV.primitive_restart',
    'OpenGL.GL.NV.register_combiners',
    'OpenGL.GL.NV.register_combiners2',
    'OpenGL.GL.NV.texgen_emboss',
    'OpenGL.GL.NV.texgen_reflection',
    'OpenGL.GL.NV.texture_compression_vtc',
    'OpenGL.GL.NV.texture_env_combine4',
    'OpenGL.GL.NV.texture_expand_normal',
    'OpenGL.GL.NV.texture_rectangle',
    'OpenGL.GL.NV.texture_shader',
    'OpenGL.GL.NV.texture_shader2',
    'OpenGL.GL.NV.texture_shader3',
    'OpenGL.GL.NV.transform_feedback',
    'OpenGL.GL.NV.vertex_array_range',
    'OpenGL.GL.NV.vertex_array_range2',
    'OpenGL.GL.NV.vertex_program',
    'OpenGL.GL.NV.vertex_program1_1',
    'OpenGL.GL.NV.vertex_program2',
    'OpenGL.GL.NV.vertex_program2_option',
    'OpenGL.GL.NV.vertex_program3',
    'OpenGL.GL.NV.vertex_program4',
    'OpenGL.GL.OES.read_format',
    'OpenGL.GL.OML.interlace',
    'OpenGL.GL.OML.resample',
    'OpenGL.GL.OML.subsample',
    'OpenGL.GL.PGI.misc_hints',
    'OpenGL.GL.PGI.vertex_hints',
    'OpenGL.GL.REND.screen_coordinates',
    'OpenGL.GL.S3.s3tc',
    'OpenGL.GL.SGI.color_matrix',
    'OpenGL.GL.SGI.color_table',
    'OpenGL.GL.SGI.depth_pass_instrument',
    'OpenGL.GL.SGI.texture_color_table',
    'OpenGL.GL.SGIS.detail_texture',
    'OpenGL.GL.SGIS.fog_function',
    'OpenGL.GL.SGIS.generate_mipmap',
    'OpenGL.GL.SGIS.multisample',
    'OpenGL.GL.SGIS.pixel_texture',
    'OpenGL.GL.SGIS.point_line_texgen',
    'OpenGL.GL.SGIS.point_parameters',
    'OpenGL.GL.SGIS.sharpen_texture',
    'OpenGL.GL.SGIS.texture4D',
    'OpenGL.GL.SGIS.texture_border_clamp',
    'OpenGL.GL.SGIS.texture_color_mask',
    'OpenGL.GL.SGIS.texture_edge_clamp',
    'OpenGL.GL.SGIS.texture_filter4',
    'OpenGL.GL.SGIS.texture_lod',
    'OpenGL.GL.SGIS.texture_select',
    'OpenGL.GL.SGIX.FfdMask',
    'OpenGL.GL.SGIX.async',
    'OpenGL.GL.SGIX.async_histogram',
    'OpenGL.GL.SGIX.async_pixel',
    'OpenGL.GL.SGIX.blend_alpha_minmax',
    'OpenGL.GL.SGIX.calligraphic_fragment',
    'OpenGL.GL.SGIX.clipmap',
    'OpenGL.GL.SGIX.convolution_accuracy',
    'OpenGL.GL.SGIX.depth_pass_instrument',
    'OpenGL.GL.SGIX.depth_texture',
    'OpenGL.GL.SGIX.flush_raster',
    'OpenGL.GL.SGIX.fog_offset',
    'OpenGL.GL.SGIX.fog_scale',
    'OpenGL.GL.SGIX.fragment_lighting',
    'OpenGL.GL.SGIX.framezoom',
    'OpenGL.GL.SGIX.igloo_interface',
    'OpenGL.GL.SGIX.impact_pixel_texture',
    'OpenGL.GL.SGIX.instruments',
    'OpenGL.GL.SGIX.interlace',
    'OpenGL.GL.SGIX.ir_instrument1',
    'OpenGL.GL.SGIX.list_priority',
    'OpenGL.GL.SGIX.pixel_texture',
    'OpenGL.GL.SGIX.pixel_tiles',
    'OpenGL.GL.SGIX.polynomial_ffd',
    'OpenGL.GL.SGIX.reference_plane',
    'OpenGL.GL.SGIX.resample',
    'OpenGL.GL.SGIX.scalebias_hint',
    'OpenGL.GL.SGIX.shadow',
    'OpenGL.GL.SGIX.shadow_ambient',
    'OpenGL.GL.SGIX.sprite',
    'OpenGL.GL.SGIX.subsample',
    'OpenGL.GL.SGIX.tag_sample_buffer',
    'OpenGL.GL.SGIX.texture_add_env',
    'OpenGL.GL.SGIX.texture_coordinate_clamp',
    'OpenGL.GL.SGIX.texture_lod_bias',
    'OpenGL.GL.SGIX.texture_multi_buffer',
    'OpenGL.GL.SGIX.texture_scale_bias',
    'OpenGL.GL.SGIX.texture_select',
    'OpenGL.GL.SGIX.vertex_preclip',
    'OpenGL.GL.SGIX.ycrcb',
    'OpenGL.GL.SGIX.ycrcb_subsample',
    'OpenGL.GL.SGIX.ycrcba',
    'OpenGL.GL.SUN.convolution_border_modes',
    'OpenGL.GL.SUN.global_alpha',
    'OpenGL.GL.SUN.mesh_array',
    'OpenGL.GL.SUN.slice_accum',
    'OpenGL.GL.SUN.triangle_list',
    'OpenGL.GL.SUN.vertex',
    'OpenGL.GL.SUNX.constant_data',
    'OpenGL.GL.VERSION.GL_1_2',
    'OpenGL.GL.VERSION.GL_1_2_images',
    'OpenGL.GL.VERSION.GL_1_3',
    'OpenGL.GL.VERSION.GL_1_3_images',
    'OpenGL.GL.VERSION.GL_1_4',
    'OpenGL.GL.VERSION.GL_1_5',
    'OpenGL.GL.VERSION.GL_2_0',
    'OpenGL.GL.VERSION.GL_2_1',
    'OpenGL.GL.VERSION.GL_3_0',
    'OpenGL.GL.WIN.phong_shading',
    'OpenGL.GL.WIN.specular_fog',
    'OpenGL.GL.exceptional',
    'OpenGL.GL.feedback',
    'OpenGL.GL.glget',
    'OpenGL.GL.images',
    'OpenGL.GL.pointers',
    'OpenGL.GL.selection',
    'OpenGL.GLE.exceptional',
    'OpenGL.GLU.EXT.nurbs_tessellator',
    'OpenGL.GLU.EXT.object_space_tess',
    'OpenGL.GLU.glunurbs',
    'OpenGL.GLU.glustruct',
    'OpenGL.GLU.projection',
    'OpenGL.GLU.quadrics',
    'OpenGL.GLU.tess',
    'OpenGL.GLUT.fonts',
    'OpenGL.GLUT.freeglut',
    'OpenGL.GLUT.special',
    'OpenGL.arrays._numeric',
    'OpenGL.arrays._strings',
    'OpenGL.arrays.arraydatatype',
    'OpenGL.arrays.arrayhelpers',
    'OpenGL.arrays.ctypesarrays',
    'OpenGL.arrays.ctypesparameters',
    'OpenGL.arrays.ctypespointers',
    'OpenGL.arrays.formathandler',
    'OpenGL.arrays.lists',
    'OpenGL.arrays.nones',
    'OpenGL.arrays.numarrays',
    'OpenGL.arrays.numbers',
    'OpenGL.arrays.numeric',
    'OpenGL.arrays.numericnames',
    'OpenGL.arrays.numpymodule',
    'OpenGL.arrays.strings',
    'OpenGL.arrays.vbo',
    'OpenGL.constant',
    'OpenGL.constants',
    'OpenGL.contextdata',
    'OpenGL.converters',
    'OpenGL.error',
    'OpenGL.extensions',
    'OpenGL.images',
    'OpenGL.lazywrapper',
    'OpenGL.logs',
    'OpenGL.platform.baseplatform',
    'OpenGL.platform.ctypesloader',
    'OpenGL.platform.darwin',
    'OpenGL.platform.glx',
    'OpenGL.platform.win32',
    'OpenGL.plugins',
    'OpenGL.raw.GL.APPLE.client_storage',
    'OpenGL.raw.GL.APPLE.element_array',
    'OpenGL.raw.GL.APPLE.fence',
    'OpenGL.raw.GL.APPLE.flush_buffer_range',
    'OpenGL.raw.GL.APPLE.specular_vector',
    'OpenGL.raw.GL.APPLE.transform_hint',
    'OpenGL.raw.GL.APPLE.vertex_array_object',
    'OpenGL.raw.GL.APPLE.vertex_array_range',
    'OpenGL.raw.GL.APPLE.ycbcr_422',
    'OpenGL.raw.GL.ARB.color_buffer_float',
    'OpenGL.raw.GL.ARB.depth_buffer_float',
    'OpenGL.raw.GL.ARB.depth_texture',
    'OpenGL.raw.GL.ARB.draw_buffers',
    'OpenGL.raw.GL.ARB.draw_instanced',
    'OpenGL.raw.GL.ARB.fragment_program',
    'OpenGL.raw.GL.ARB.fragment_program_shadow',
    'OpenGL.raw.GL.ARB.fragment_shader',
    'OpenGL.raw.GL.ARB.framebuffer_object',
    'OpenGL.raw.GL.ARB.framebuffer_sRGB',
    'OpenGL.raw.GL.ARB.geometry_shader4',
    'OpenGL.raw.GL.ARB.half_float_pixel',
    'OpenGL.raw.GL.ARB.half_float_vertex',
    'OpenGL.raw.GL.ARB.imaging',
    'OpenGL.raw.GL.ARB.instanced_arrays',
    'OpenGL.raw.GL.ARB.map_buffer_range',
    'OpenGL.raw.GL.ARB.matrix_palette',
    'OpenGL.raw.GL.ARB.multisample',
    'OpenGL.raw.GL.ARB.multitexture',
    'OpenGL.raw.GL.ARB.occlusion_query',
    'OpenGL.raw.GL.ARB.pixel_buffer_object',
    'OpenGL.raw.GL.ARB.point_parameters',
    'OpenGL.raw.GL.ARB.point_sprite',
    'OpenGL.raw.GL.ARB.shader_objects',
    'OpenGL.raw.GL.ARB.shading_language_100',
    'OpenGL.raw.GL.ARB.shadow',
    'OpenGL.raw.GL.ARB.shadow_ambient',
    'OpenGL.raw.GL.ARB.texture_border_clamp',
    'OpenGL.raw.GL.ARB.texture_buffer_object',
    'OpenGL.raw.GL.ARB.texture_compression',
    'OpenGL.raw.GL.ARB.texture_compression_rgtc',
    'OpenGL.raw.GL.ARB.texture_cube_map',
    'OpenGL.raw.GL.ARB.texture_env_add',
    'OpenGL.raw.GL.ARB.texture_env_combine',
    'OpenGL.raw.GL.ARB.texture_env_crossbar',
    'OpenGL.raw.GL.ARB.texture_env_dot3',
    'OpenGL.raw.GL.ARB.texture_float',
    'OpenGL.raw.GL.ARB.texture_mirrored_repeat',
    'OpenGL.raw.GL.ARB.texture_non_power_of_two',
    'OpenGL.raw.GL.ARB.texture_rectangle',
    'OpenGL.raw.GL.ARB.texture_rg',
    'OpenGL.raw.GL.ARB.transpose_matrix',
    'OpenGL.raw.GL.ARB.vertex_array_object',
    'OpenGL.raw.GL.ARB.vertex_blend',
    'OpenGL.raw.GL.ARB.vertex_buffer_object',
    'OpenGL.raw.GL.ARB.vertex_program',
    'OpenGL.raw.GL.ARB.vertex_shader',
    'OpenGL.raw.GL.ARB.window_pos',
    'OpenGL.raw.GL.ATI.draw_buffers',
    'OpenGL.raw.GL.ATI.element_array',
    'OpenGL.raw.GL.ATI.envmap_bumpmap',
    'OpenGL.raw.GL.ATI.fragment_shader',
    'OpenGL.raw.GL.ATI.map_object_buffer',
    'OpenGL.raw.GL.ATI.pixel_format_float',
    'OpenGL.raw.GL.ATI.pn_triangles',
    'OpenGL.raw.GL.ATI.separate_stencil',
    'OpenGL.raw.GL.ATI.text_fragment_shader',
    'OpenGL.raw.GL.ATI.texture_env_combine3',
    'OpenGL.raw.GL.ATI.texture_float',
    'OpenGL.raw.GL.ATI.texture_mirror_once',
    'OpenGL.raw.GL.ATI.vertex_array_object',
    'OpenGL.raw.GL.ATI.vertex_attrib_array_object',
    'OpenGL.raw.GL.ATI.vertex_streams',
    'OpenGL.raw.GL.DFX.multisample',
    'OpenGL.raw.GL.DFX.tbuffer',
    'OpenGL.raw.GL.DFX.texture_compression_FXT1',
    'OpenGL.raw.GL.EXT.422_pixels',
    'OpenGL.raw.GL.EXT.GL_422_pixels',
    'OpenGL.raw.GL.EXT.abgr',
    'OpenGL.raw.GL.EXT.bgra',
    'OpenGL.raw.GL.EXT.bindable_uniform',
    'OpenGL.raw.GL.EXT.blend_color',
    'OpenGL.raw.GL.EXT.blend_equation_separate',
    'OpenGL.raw.GL.EXT.blend_func_separate',
    'OpenGL.raw.GL.EXT.blend_logic_op',
    'OpenGL.raw.GL.EXT.blend_minmax',
    'OpenGL.raw.GL.EXT.blend_subtract',
    'OpenGL.raw.GL.EXT.clip_volume_hint',
    'OpenGL.raw.GL.EXT.cmyka',
    'OpenGL.raw.GL.EXT.color_matrix',
    'OpenGL.raw.GL.EXT.color_subtable',
    'OpenGL.raw.GL.EXT.compiled_vertex_array',
    'OpenGL.raw.GL.EXT.convolution',
    'OpenGL.raw.GL.EXT.coordinate_frame',
    'OpenGL.raw.GL.EXT.copy_texture',
    'OpenGL.raw.GL.EXT.cull_vertex',
    'OpenGL.raw.GL.EXT.depth_bounds_test',
    'OpenGL.raw.GL.EXT.draw_buffers2',
    'OpenGL.raw.GL.EXT.draw_instanced',
    'OpenGL.raw.GL.EXT.draw_range_elements',
    'OpenGL.raw.GL.EXT.fog_coord',
    'OpenGL.raw.GL.EXT.framebuffer_blit',
    'OpenGL.raw.GL.EXT.framebuffer_multisample',
    'OpenGL.raw.GL.EXT.framebuffer_object',
    'OpenGL.raw.GL.EXT.framebuffer_sRGB',
    'OpenGL.raw.GL.EXT.geometry_shader4',
    'OpenGL.raw.GL.EXT.gpu_program_parameters',
    'OpenGL.raw.GL.EXT.gpu_shader4',
    'OpenGL.raw.GL.EXT.histogram',
    'OpenGL.raw.GL.EXT.index_array_formats',
    'OpenGL.raw.GL.EXT.index_func',
    'OpenGL.raw.GL.EXT.index_material',
    'OpenGL.raw.GL.EXT.index_texture',
    'OpenGL.raw.GL.EXT.light_texture',
    'OpenGL.raw.GL.EXT.misc_attribute',
    'OpenGL.raw.GL.EXT.multi_draw_arrays',
    'OpenGL.raw.GL.EXT.multisample',
    'OpenGL.raw.GL.EXT.packed_depth_stencil',
    'OpenGL.raw.GL.EXT.packed_float',
    'OpenGL.raw.GL.EXT.packed_pixels',
    'OpenGL.raw.GL.EXT.paletted_texture',
    'OpenGL.raw.GL.EXT.pixel_buffer_object',
    'OpenGL.raw.GL.EXT.pixel_transform',
    'OpenGL.raw.GL.EXT.pixel_transform_color_table',
    'OpenGL.raw.GL.EXT.point_parameters',
    'OpenGL.raw.GL.EXT.polygon_offset',
    'OpenGL.raw.GL.EXT.rescale_normal',
    'OpenGL.raw.GL.EXT.secondary_color',
    'OpenGL.raw.GL.EXT.separate_specular_color',
    'OpenGL.raw.GL.EXT.shadow_funcs',
    'OpenGL.raw.GL.EXT.shared_texture_palette',
    'OpenGL.raw.GL.EXT.stencil_clear_tag',
    'OpenGL.raw.GL.EXT.stencil_two_side',
    'OpenGL.raw.GL.EXT.stencil_wrap',
    'OpenGL.raw.GL.EXT.subtexture',
    'OpenGL.raw.GL.EXT.texture',
    'OpenGL.raw.GL.EXT.texture3D',
    'OpenGL.raw.GL.EXT.texture_array',
    'OpenGL.raw.GL.EXT.texture_buffer_object',
    'OpenGL.raw.GL.EXT.texture_compression_latc',
    'OpenGL.raw.GL.EXT.texture_compression_rgtc',
    'OpenGL.raw.GL.EXT.texture_compression_s3tc',
    'OpenGL.raw.GL.EXT.texture_cube_map',
    'OpenGL.raw.GL.EXT.texture_env_add',
    'OpenGL.raw.GL.EXT.texture_env_combine',
    'OpenGL.raw.GL.EXT.texture_env_dot3',
    'OpenGL.raw.GL.EXT.texture_filter_anisotropic',
    'OpenGL.raw.GL.EXT.texture_integer',
    'OpenGL.raw.GL.EXT.texture_lod_bias',
    'OpenGL.raw.GL.EXT.texture_mirror_clamp',
    'OpenGL.raw.GL.EXT.texture_object',
    'OpenGL.raw.GL.EXT.texture_perturb_normal',
    'OpenGL.raw.GL.EXT.texture_sRGB',
    'OpenGL.raw.GL.EXT.texture_shared_exponent',
    'OpenGL.raw.GL.EXT.timer_query',
    'OpenGL.raw.GL.EXT.transform_feedback',
    'OpenGL.raw.GL.EXT.vertex_array',
    'OpenGL.raw.GL.EXT.vertex_shader',
    'OpenGL.raw.GL.EXT.vertex_weighting',
    'OpenGL.raw.GL.GREMEDY.frame_terminator',
    'OpenGL.raw.GL.GREMEDY.string_marker',
    'OpenGL.raw.GL.HP.convolution_border_modes',
    'OpenGL.raw.GL.HP.image_transform',
    'OpenGL.raw.GL.HP.occlusion_test',
    'OpenGL.raw.GL.HP.texture_lighting',
    'OpenGL.raw.GL.IBM.cull_vertex',
    'OpenGL.raw.GL.IBM.multimode_draw_arrays',
    'OpenGL.raw.GL.IBM.rasterpos_clip',
    'OpenGL.raw.GL.IBM.texture_mirrored_repeat',
    'OpenGL.raw.GL.IBM.vertex_array_lists',
    'OpenGL.raw.GL.INGR.blend_func_separate',
    'OpenGL.raw.GL.INGR.color_clamp',
    'OpenGL.raw.GL.INGR.interlace_read',
    'OpenGL.raw.GL.INGR.palette_buffer',
    'OpenGL.raw.GL.INTEL.parallel_arrays',
    'OpenGL.raw.GL.INTEL.texture_scissor',
    'OpenGL.raw.GL.MESA.pack_invert',
    'OpenGL.raw.GL.MESA.resize_buffers',
    'OpenGL.raw.GL.MESA.window_pos',
    'OpenGL.raw.GL.MESA.ycbcr_texture',
    'OpenGL.raw.GL.MESAX.texture_stack',
    'OpenGL.raw.GL.NV.blend_square',
    'OpenGL.raw.GL.NV.conditional_render',
    'OpenGL.raw.GL.NV.copy_depth_to_color',
    'OpenGL.raw.GL.NV.depth_buffer_float',
    'OpenGL.raw.GL.NV.depth_clamp',
    'OpenGL.raw.GL.NV.evaluators',
    'OpenGL.raw.GL.NV.fence',
    'OpenGL.raw.GL.NV.float_buffer',
    'OpenGL.raw.GL.NV.fog_distance',
    'OpenGL.raw.GL.NV.fragment_program',
    'OpenGL.raw.GL.NV.fragment_program2',
    'OpenGL.raw.GL.NV.fragment_program4',
    'OpenGL.raw.GL.NV.fragment_program_option',
    'OpenGL.raw.GL.NV.framebuffer_multisample_coverage',
    'OpenGL.raw.GL.NV.geometry_program4',
    'OpenGL.raw.GL.NV.geometry_shader4',
    'OpenGL.raw.GL.NV.gpu_program4',
    'OpenGL.raw.GL.NV.half_float',
    'OpenGL.raw.GL.NV.light_max_exponent',
    'OpenGL.raw.GL.NV.multisample_filter_hint',
    'OpenGL.raw.GL.NV.occlusion_query',
    'OpenGL.raw.GL.NV.packed_depth_stencil',
    'OpenGL.raw.GL.NV.parameter_buffer_object',
    'OpenGL.raw.GL.NV.pixel_data_range',
    'OpenGL.raw.GL.NV.point_sprite',
    'OpenGL.raw.GL.NV.present_video',
    'OpenGL.raw.GL.NV.primitive_restart',
    'OpenGL.raw.GL.NV.register_combiners',
    'OpenGL.raw.GL.NV.register_combiners2',
    'OpenGL.raw.GL.NV.texgen_emboss',
    'OpenGL.raw.GL.NV.texgen_reflection',
    'OpenGL.raw.GL.NV.texture_compression_vtc',
    'OpenGL.raw.GL.NV.texture_env_combine4',
    'OpenGL.raw.GL.NV.texture_expand_normal',
    'OpenGL.raw.GL.NV.texture_rectangle',
    'OpenGL.raw.GL.NV.texture_shader',
    'OpenGL.raw.GL.NV.texture_shader2',
    'OpenGL.raw.GL.NV.texture_shader3',
    'OpenGL.raw.GL.NV.transform_feedback',
    'OpenGL.raw.GL.NV.vertex_array_range',
    'OpenGL.raw.GL.NV.vertex_array_range2',
    'OpenGL.raw.GL.NV.vertex_program',
    'OpenGL.raw.GL.NV.vertex_program1_1',
    'OpenGL.raw.GL.NV.vertex_program2',
    'OpenGL.raw.GL.NV.vertex_program2_option',
    'OpenGL.raw.GL.NV.vertex_program3',
    'OpenGL.raw.GL.NV.vertex_program4',
    'OpenGL.raw.GL.OES.read_format',
    'OpenGL.raw.GL.OML.interlace',
    'OpenGL.raw.GL.OML.resample',
    'OpenGL.raw.GL.OML.subsample',
    'OpenGL.raw.GL.PGI.misc_hints',
    'OpenGL.raw.GL.PGI.vertex_hints',
    'OpenGL.raw.GL.REND.screen_coordinates',
    'OpenGL.raw.GL.S3.s3tc',
    'OpenGL.raw.GL.SGI.color_matrix',
    'OpenGL.raw.GL.SGI.color_table',
    'OpenGL.raw.GL.SGI.depth_pass_instrument',
    'OpenGL.raw.GL.SGI.texture_color_table',
    'OpenGL.raw.GL.SGIS.detail_texture',
    'OpenGL.raw.GL.SGIS.fog_function',
    'OpenGL.raw.GL.SGIS.generate_mipmap',
    'OpenGL.raw.GL.SGIS.multisample',
    'OpenGL.raw.GL.SGIS.pixel_texture',
    'OpenGL.raw.GL.SGIS.point_line_texgen',
    'OpenGL.raw.GL.SGIS.point_parameters',
    'OpenGL.raw.GL.SGIS.sharpen_texture',
    'OpenGL.raw.GL.SGIS.texture4D',
    'OpenGL.raw.GL.SGIS.texture_border_clamp',
    'OpenGL.raw.GL.SGIS.texture_color_mask',
    'OpenGL.raw.GL.SGIS.texture_edge_clamp',
    'OpenGL.raw.GL.SGIS.texture_filter4',
    'OpenGL.raw.GL.SGIS.texture_lod',
    'OpenGL.raw.GL.SGIS.texture_select',
    'OpenGL.raw.GL.SGIX.FfdMask',
    'OpenGL.raw.GL.SGIX.async',
    'OpenGL.raw.GL.SGIX.async_histogram',
    'OpenGL.raw.GL.SGIX.async_pixel',
    'OpenGL.raw.GL.SGIX.blend_alpha_minmax',
    'OpenGL.raw.GL.SGIX.calligraphic_fragment',
    'OpenGL.raw.GL.SGIX.clipmap',
    'OpenGL.raw.GL.SGIX.convolution_accuracy',
    'OpenGL.raw.GL.SGIX.depth_pass_instrument',
    'OpenGL.raw.GL.SGIX.depth_texture',
    'OpenGL.raw.GL.SGIX.flush_raster',
    'OpenGL.raw.GL.SGIX.fog_offset',
    'OpenGL.raw.GL.SGIX.fog_scale',
    'OpenGL.raw.GL.SGIX.fragment_lighting',
    'OpenGL.raw.GL.SGIX.framezoom',
    'OpenGL.raw.GL.SGIX.igloo_interface',
    'OpenGL.raw.GL.SGIX.impact_pixel_texture',
    'OpenGL.raw.GL.SGIX.instruments',
    'OpenGL.raw.GL.SGIX.interlace',
    'OpenGL.raw.GL.SGIX.ir_instrument1',
    'OpenGL.raw.GL.SGIX.list_priority',
    'OpenGL.raw.GL.SGIX.pixel_texture',
    'OpenGL.raw.GL.SGIX.pixel_tiles',
    'OpenGL.raw.GL.SGIX.polynomial_ffd',
    'OpenGL.raw.GL.SGIX.reference_plane',
    'OpenGL.raw.GL.SGIX.resample',
    'OpenGL.raw.GL.SGIX.scalebias_hint',
    'OpenGL.raw.GL.SGIX.shadow',
    'OpenGL.raw.GL.SGIX.shadow_ambient',
    'OpenGL.raw.GL.SGIX.sprite',
    'OpenGL.raw.GL.SGIX.subsample',
    'OpenGL.raw.GL.SGIX.tag_sample_buffer',
    'OpenGL.raw.GL.SGIX.texture_add_env',
    'OpenGL.raw.GL.SGIX.texture_coordinate_clamp',
    'OpenGL.raw.GL.SGIX.texture_lod_bias',
    'OpenGL.raw.GL.SGIX.texture_multi_buffer',
    'OpenGL.raw.GL.SGIX.texture_scale_bias',
    'OpenGL.raw.GL.SGIX.texture_select',
    'OpenGL.raw.GL.SGIX.vertex_preclip',
    'OpenGL.raw.GL.SGIX.ycrcb',
    'OpenGL.raw.GL.SGIX.ycrcb_subsample',
    'OpenGL.raw.GL.SGIX.ycrcba',
    'OpenGL.raw.GL.SUN.convolution_border_modes',
    'OpenGL.raw.GL.SUN.global_alpha',
    'OpenGL.raw.GL.SUN.mesh_array',
    'OpenGL.raw.GL.SUN.slice_accum',
    'OpenGL.raw.GL.SUN.triangle_list',
    'OpenGL.raw.GL.SUN.vertex',
    'OpenGL.raw.GL.SUNX.constant_data',
    'OpenGL.raw.GL.VERSION.GL_1_2',
    'OpenGL.raw.GL.VERSION.GL_1_3',
    'OpenGL.raw.GL.VERSION.GL_1_4',
    'OpenGL.raw.GL.VERSION.GL_1_5',
    'OpenGL.raw.GL.VERSION.GL_2_0',
    'OpenGL.raw.GL.VERSION.GL_2_1',
    'OpenGL.raw.GL.VERSION.GL_3_0',
    'OpenGL.raw.GL.WIN.phong_shading',
    'OpenGL.raw.GL.WIN.specular_fog',
    'OpenGL.raw.GL.annotations',
    'OpenGL.raw.GL.constants',
    'OpenGL.raw.GLE.annotations',
    'OpenGL.raw.GLE.constants',
    'OpenGL.raw.GLU.annotations',
    'OpenGL.raw.GLU.constants',
    'OpenGL.raw.GLUT.annotations',
    'OpenGL.raw.GLUT.constants',
    'OpenGL.raw.GLX',
    'OpenGL.raw.WGL',
    'OpenGL.raw._GLX',
    'OpenGL.raw._GLX_ARB',
    'OpenGL.raw._GLX_NV',
    'OpenGL.raw._WGL',
    'OpenGL.raw._WGL_ARB',
    'OpenGL.raw._WGL_NV',
    'OpenGL.version',
    'OpenGL.wrapper',
]

exclude_list = [
    '_ssl',
    'pyreadline',
    'difflib',
    'doctest',
    'locale',
    'optparse',
    'unittest',
    'pdb',
    'calendar'
]

main = 'source/main.py'
name = 'Norwegian Wood'

data_files = [
    ('resources',
     glob.glob('resources/*.png')
     + glob.glob('resources/*.ttf')
     + glob.glob('resources/*.txt')),
    ('resources/sprites',
     glob.glob('resources/sprites/*.png'))
]

if sys.platform == 'darwin':
    extra_options = {
        'app': [main],
        'setup_requires': ['py2app'],
        'name': name,
        'options': {
            'py2app': {
                'argv_emulation': True,
                'includes': opengl_modules,
                'excludes': exclude_list,
                'iconfile': 'john.icns'
                }
            }
        }
else:
    assert sys.platform == 'win32'
    import py2exe
    extra_options = {
        'windows': [{
            'script': main,
            'dest_base': name,
            "icon_resources": [(1, "john.ico")]
            }],
        'setup_requires': ['py2exe'],
        'options': {
            'py2exe': {
                'includes': opengl_modules,
                'excludes': exclude_list,
                'bundle_files': 2,
                'compressed': True
                }
            }
        }

setup(data_files=data_files, **extra_options)