"""Record multiplier changes and collisions."""

from time import time
from OpenGL.GL import *
from OpenGL.GLU import *

song_length = 130 #seconds
x_mod = 4
y_mod = -30

class Log(object):    
    def __init__(self):
        self.__base_time = int(time())
        self.__collisions = []
        self.__multipliers = [(0, 1)]
        self.__last_time = 0
     
    def record_collision(self):
        self.__collisions.append(int(time()) - self.__base_time)
        
    def record_multiplier(self, multiplier):
        current_time = int(time())
        #Remove very small multiplier times
        if (current_time - self.__last_time) < 1 :
            self.__multipliers.pop()
        if (current_time - self.__base_time) < song_length :
            self.__multipliers.append((current_time - self.__base_time, multiplier))
            self.__last_time = current_time
        
    def get_hit_count(self):
        return len(self.__collisions)
        
    def draw(self, opacity):
        """Draw a graph of the multiplier performance over time."""
        self.__draw_boxes(opacity)
        self.__draw_lines(opacity)
        
    def __draw_boxes(self, opacity):
        """Draw the outline of the multiplier performance."""
        glColor(0.7, 0.7, 0.7, opacity)
        glBegin(GL_QUADS)
        
        last_x = x_mod * 0
        last_y = y_mod * 1
        for entry in self.__multipliers :
            x = entry[0] * x_mod
            y = entry[1] * y_mod
            glVertex(x, last_y)
            glVertex(x, 0)
            glVertex(last_x, 0)
            glVertex(last_x, last_y)
            last_x = x
            last_y = y
        glVertex(song_length * x_mod, last_y)
        glVertex(song_length * x_mod, 0)
        glVertex(last_x, 0)
        glVertex(last_x, last_y)
        
        glColor(1, 1, 1)
        glEnd()

    def __draw_lines(self, opacity):
        """Draw the boxes multiplier performance."""
        glColor(0, 0, 0, opacity)
        glBegin(GL_LINE_STRIP)
        
        glVertex(0, 0)
        last_x = 0
        last_y = 0
        for entry in self.__multipliers :
            x = entry[0] * x_mod
            y = entry[1] * y_mod
            glVertex(x, last_y)
            glVertex(x, y)
            last_x = x
            last_y = y
        glVertex(song_length * x_mod, last_y)
        glVertex(song_length * x_mod, 0)
        
        glColor(1, 1, 1)
        glEnd()