"""Handles functionality related to high scores."""

import hashlib 
import pickle
import base64
import httplib
import urllib
import os
from time import time

import resources

class Scores(object):
    
    high_scores = [
        (100, "KYLE"),
        (200, "WILL"),
        (300, "ALEX"),
        (400, "RENAUD"),
        (500, "PHIL"),
        (600, "THOMAS"),
        (700, "MATTHEW"),
        (800, "HENK"),
        (900, "FUN"),
        (1000, "NO")]
    
    def add_score(self, name, score, hit_count):
        self.high_scores.append((score, name))
        self.high_scores.sort()
        self.high_scores.reverse()
        self.high_scores = self.high_scores[0:10]
    
    def get_high_scores(self):
        return self.high_scores

#### Utility ################################################################## 

#Random salt
key = "THISISARANDOMSALT"

def record_score(name, score, hit_count):
    #Records the score locally
    #Load local High Scores from file
    try:
        input = open(os.path.join(resources._resource_path, "..", "data"), "r")
        high_scores = pickle.loads(base64.b64decode(input.read()))
        input.close()
    except Exception:
        high_scores = Scores()
    
    #Add new score
    high_scores.add_score(name, score, hit_count)
    
    #Save local updated high scores to file
    output = open(os.path.join(resources._resource_path, "..", "data"), "w")
    output_string = base64.b64encode(pickle.dumps(high_scores))
    output.write(output_string)
    output.close()
    
    return high_scores
    
def send_score(name, score, hit_count):
    #Sends the score to the server
    #Create a hash to verify authenticity
    time_stamp = int(time())
    hash = hashlib.md5("%s %s %s %s %s" % (name, str(score), str(time_stamp), str(hit_count), key)).hexdigest()
    
    #Send Score to server
    params = urllib.urlencode({'name': name, 'score': score, 'time': time_stamp, 'hit_count': hit_count, 'hash': hash})
    headers = {"Content-type": "application/x-www-form-urlencoded", "Accept": "text/plain"}
    global_high_scores = ()
    response_data = 5 #default error message
    try:
        conn = httplib.HTTPConnection('norwegianwood.gangles.ca',80)
        conn.request('POST', '/cgi-bin/submit_score.py', params, headers)
        response = conn.getresponse()
        response_data = response.read()
        
        global_data = pickle.loads(base64.b64decode(response_data))
    
        (global_rank, global_scores) = global_data 
        high_scores_list = []
        if (global_rank <=10):
            for row in global_scores:
                high_scores_list.append(row)
            global_high_scores = (global_rank, high_scores_list) 
    
        else:
            for row in global_scores[0]:
                high_scores_list.append(row)
            for row in global_scores[1]:
                high_scores_list.append(row)
            global_high_scores = (global_rank, high_scores_list) 
    except Exception:
        global_high_scores = (0, int(response_data))
    
    return global_high_scores
