"""Utility functions."""

from vector2d import *

def actors_collide(actor1, actor2):
    if actor1.radius == None or actor2.radius == None:
        return false

    distance_squared =  _moving_points_distance_squared(
        actor1.old_pos or actor1.pos,
        actor1.pos,
        actor2.old_pos or actor2.pos,
        actor2.pos)
    
    collision_distance = actor1.radius + actor2.radius
    return distance_squared < collision_distance * collision_distance

def _moving_points_distance_squared(a1, a2, b1, b2):
    """Returns distance between points moving from a1 to a2 and b1 to b2."""
    return _origin_to_segment_distance_squared(b1 - a1, b2 - a2)

def _origin_to_segment_distance_squared(p1, p2):
    """Returns the distance between the origin and the p1,p2 line segment."""
    run = p2 - p1
    run_squared = run.magnitude_squared()

    # if the segment is of zero length, it's just the distance to one of the
    # points
    if run_squared == 0:
        return p1.magnitude_squared()

    # project the origin onto the p1+t*run line, finding the value of t
    t = -p1.dot(run) / run_squared

    if t < 0:
        # if t is negative, then the first point is closest
        return p1.magnitude_squared()
    elif t < 1:
        # if t is between 0 and 1, then the point lies on the line segment
        return (p1 + run * t).magnitude_squared()
    else:
        # if t is greater than one, then the second point is closest
        return p2.magnitude_squared()
