import actor
import behaviors
import resources
import math
from vector2d import Vector2d

bullet_speed = 3.

def _add_with_behaviors(game, pos, sprite_name, type, *behavior):
    bullet = actor.ScriptedActor(
        game,
        pos,
        resources.animation_sets[sprite_name],
        type)
    bullet.push_behavior(*behavior)
    game.add_actor(bullet)

def targeted(game, pos):
    vel = game.get_target() - pos
    if not vel.is_zero():
        vel = vel.get_normalized() * bullet_speed * game.get_speed_mod()
        _add_with_behaviors(game, pos, "down_eighth", "enemy",
            behaviors.change_velocity(vel))

def leading(game, pos):
    vel = game.get_target() - pos
    dist = vel.magnitude()
    vel += dist * game.get_vel() / 6.0
    if not vel.is_zero():
        vel = vel.get_normalized() * bullet_speed * game.get_speed_mod()
        _add_with_behaviors(game, pos, "up_eighth", "enemy",
            behaviors.change_velocity(vel))

def targeted_spread(game, pos):
    vel = game.get_target() - pos
    if not vel.is_zero():
        vel = vel.get_normalized() * bullet_speed * game.get_speed_mod()
        _add_with_behaviors(game, pos, "double_sixteenth", "enemy",
            behaviors.change_velocity(vel))
        _add_with_behaviors(game, pos, "double_sixteenth", "enemy",
            behaviors.change_velocity(vel.rotate(0.35)))
        _add_with_behaviors(game, pos, "double_sixteenth", "enemy",
            behaviors.change_velocity(vel.rotate(-0.35)))
        _add_with_behaviors(game, pos, "double_sixteenth", "enemy",
            behaviors.change_velocity(vel.rotate(0.7)))
        _add_with_behaviors(game, pos, "double_sixteenth", "enemy",
            behaviors.change_velocity(vel.rotate(-0.7)))

direct_spread_offset = 0
def direct_spread(game, pos):
    global direct_spread_offset
    number = 6
    diff = 0
    if direct_spread_offset :
        diff = math.pi / 32
    vel = Vector2d(-1,0) * bullet_speed * game.get_speed_mod()
    angle = math.pi / (number * 2)
    for i in range (0, number):
        _add_with_behaviors(game, pos, "quarter", "enemy",
            behaviors.change_velocity(vel.rotate(angle * i + diff)))
    direct_spread_offset = not direct_spread_offset
    
#Right angle in 6 intervals (in radians)
SPRINKLER_PATTERN = [0, 0.314, 0.628, 0.942, 1.257, 1.571]
sprinkler_position = 0
def sprinkler(game, pos):
    global sprinkler_position
    vel = Vector2d(-1,0) * bullet_speed * game.get_speed_mod()
    _add_with_behaviors(game, pos, "quarter", "enemy",
        behaviors.change_velocity(vel.rotate(SPRINKLER_PATTERN[sprinkler_position])))
    sprinkler_position = (sprinkler_position + 1) % len(SPRINKLER_PATTERN)

def homing(game, pos):
    vel = game.get_target() - pos
    if not vel.is_zero():
        vel = vel.get_normalized() * bullet_speed * game.get_speed_mod()
    _add_with_behaviors(game, pos, "up_eighth", "enemy",
        behaviors.change_velocity(vel),
        behaviors.wait_for(30),
        behaviors.home_for(120))

