from OpenGL.GL import *

import graphics
import resources

class Window(object):
    """Represents a window in the Game object's window stack. """
    def update(self, game, is_on_top):
        """Called every frame to update the dialog.
        
        Keypress checking, animation, etc. should be handled here.
        """
    def draw(self, is_on_top):
        """Draws the window on screen."""

class Dimmer(Window):
    """A window which dims everything under it.
    
    This is to be placed under another window, since it removes itself as soon
    as it is on top.
    """
    def update(self, game, is_on_top):
        if is_on_top:
            game.pop_window()
    def draw(self, is_on_top):
        glColor(0, 0, 0, 0.5)
        glBegin(GL_QUADS)
        glVertex(0, 0)
        glVertex(0, 600)
        glVertex(800, 600)
        glVertex(800, 0)
        glEnd()
        glColor(1, 1, 1)

class Pause(Window):
    """Displays a sprite until the pause button is pressed."""
    def update(self, game, is_on_top):
        if is_on_top and game.key_was_pressed("pause"):
            game.pop_window()

class Dialog(Window):
    """Displays framed text to the player until he hits the ok button."""
    def __init__(self, text):
        self.text = text
        """Creates a dialog window which displays the given text."""
    def update(self, game, is_on_top):
        if is_on_top and game.key_was_pressed("ok"):
            game.pop_window()
        
    def draw(self, is_on_top):
        #TODO Replace gl calls with pretty sprite Dialog Box
        glColor(0.8, 0.8, 0.8,0.9)
        glBegin(GL_QUADS)
        glVertex(5, 175)
        glVertex(5, 235)
        glVertex(315, 235)
        glVertex(315, 175)
        glEnd()
        glColor(1, 1, 1)
        graphics.draw_string(resources.font_maps["outline"], self.text,10,180)
